# To close budget on particles

> We are activatively tidying up the code for budget closure. The process is quite slow because the boy need to prioritize on getting his PhD :P.

The pdf in this directory describes, in theory, how to close budget on Lagrangian particles using seaduck. A paper will (hopefully) be published soon on this, and there will be a proper way to cite then.

The corresponding code exists, but is a lot less tidy than this package, and is therefore in a private repo. If you would like to use this functionality, please email me (Wenrui Jiang) at wjiang33@jhu.edu. I am happy to share the code, explain things, and potentially corroborate on your project.

If you want to contribute to the package by helping me make the budget code public, also email me. I don't know how to thank you enough.
